#
# spec file for package libverto
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   1
Name:           libverto
Version:        0.3.2
Release:        3.5
Summary:        Main loop abstraction library
License:        MIT
Group:          Development/Libraries/C and C++
URL:            https://github.com/latchset/libverto
Source:         https://github.com/latchset/libverto/releases/download/%{version}/libverto-%{version}.tar.gz
Source1:        baselibs.conf
BuildRequires:  pkgconfig

%description
libverto provides a way for libraries to expose asynchronous
interfaces without having to choose a particular event loop,
offloading this decision to the end application which consumes the
library.

If you are packaging an application, not library, based on libverto,
you should depend either on a specific implementation module or you
can depend on the virtual provides 'libverto-module-base'. This will
ensure that you have at least one module installed that provides io,
timeout and signal functionality. Currently glib is the only module
that does not provide these three because it lacks signal. However,
glib will support signal in the future.

%package -n %{name}%{sover}
Summary:        Runtime libraries for libverto
Group:          Development/Libraries/C and C++

%description -n %{name}%{sover}
libverto provides a way for libraries to expose asynchronous
interfaces without having to choose a particular event loop,
offloading this decision to the end application which consumes the
library.

If you are packaging an application, not library, based on libverto,
you should depend either on a specific implementation module or you
can depend on the virtual provides 'libverto-module-base'. This will
ensure that you have at least one module installed that provides io,
timeout and signal functionality. Currently glib is the only module
that does not provide these three because it lacks signal. However,
glib will support signal in the future.

%package        devel
Summary:        Development files for libverto
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description    devel
The libverto-devel package contains libraries and header files
for developing applications that use libverto.

%prep
%setup -q

%build
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
find %{buildroot} -name '*.so.*T' -delete

%post -n libverto%{sover} -p /sbin/ldconfig
%postun -n libverto%{sover} -p /sbin/ldconfig

%files -n libverto%{sover}
%license COPYING
%doc AUTHORS ChangeLog NEWS README
%{_libdir}/%{name}.so.*

%files devel
%{_includedir}/verto.h
%{_includedir}/verto-module.h
%{_libdir}/%{name}.so
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Mon Apr 24 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Sat Sep 24 2022 Dirk Müller <dmueller@suse.com>
- update to 0.3.2:
  * Fix use-after-free in verto_reinitialize
  * Fix use-after-free in verto_free()
  * Remove broken tevent support
* Thu Aug 27 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.3.1:
  * Fix rare leak of DSO in module_load
  * Turn off -Wcast-function-type
  * Work around libev not being c89-compliant
  * Minor release bumps for verto_cleanup()
  * Leak fixes
  * Enforce strict c89 compliance for portability
  * Many warning fixes
  * Fix memleak in libverto:vfree
  * Update mutex usage to improve debugging
  * Add verto_cleanup() to free loaded_modules
  * Make C99 requirement explicit
* Thu Feb 22 2018 fvogt@suse.com
- Use %%license (boo#1082318)
* Sun Oct 29 2017 meissner@suse.com
- add libverto-devel baselib for use by libkrb5-devel-32bit,
  for use by Wine 32bit.
* Tue Jun  6 2017 hguo@suse.com
- There is no change made about the package itself, this is only
  copying over some changelog texts from SLE package:
- [fate#320326](https://fate.suse.com/320326)
* Mon May 16 2016 mlin@suse.com
- Split off libev, glib and tevent module to sub-package
* Mon Jun 22 2015 hguo@suse.com
- Remove irrelevant changelog entries from changelog file.
* Sat May 30 2015 sor.alexei@meowr.ru
- Add baselibs.conf to enable multilib.
- Spec cleanup.
* Fri May  8 2015 pth@suse.de
- Name shared library packages according to policy.
* Fri May  8 2015 hguo@suse.com
- Source extracted from Fedora 21 release SRPM, with minor adjustments.
